@@ -671,8 +671,13 @@ export class ActionHandler extends DynDep implements ActionHandler {
         }
 
         if (response.refresh || response.refresh_all) {
-            if (aH.context.APP.dashboard) aH.context.APP.dashboard.reloadData()
-            else aH.reload();
+            if (!aH.context.isSlave || !aH.context.root.props.summary)
+                aH.reload()
+            else if (aH.context.root.props.summary)
+                aH.context.root.props.summary.update();
+        }
+        if (response.refresh || response.refresh_all) {
+            if (aH.context.APP.dashboard) aH.context.APP.dashboard.reloadData();
             Object.values(aH.context.APP.URLContext.actionHandler.reloadables)
             .forEach((element:t.Reloadable) => element.reload());
         }
@@ -980,6 +985,18 @@ export class ActionHandler extends DynDep implements ActionHandler {
                 if (xhr.readyState === 4 && xhr.status >= 200 && xhr.status < 300) {
                     this.context.dataContext.mutableContext.UploadHandlerEvent = null;
                     await this.handleActionResponse({response: JSON.parse(xhr.responseText)});
+                } else if (xhr.status == 413) {
+                    this.context.APP.toast.show({
+                        severity: "error",
+                        summary: this.ex.i18n.t("Bad request"),
+                        detail: this.ex.i18n.t("File is too large! it exceeds the server upload limit"),
+                    });
+                } else {
+                    this.context.APP.toast.show({
+                        severity: "error",
+                        summary: this.ex.i18n.t("Bad request"),
+                        detail: xhr.responseText,
+                    });
                 }
             }
 
