@@ -1,4 +1,4 @@
-import(/* webpackChunkName: "prRhea_AppCSS" */'primereact/resources/themes/rhea/theme.css');
+// import(/* webpackChunkName: "prRhea_AppCSS" */'primereact/resources/themes/rhea/theme.css');
 // import 'primereact/resources/themes/rhea/theme.css';
 // import 'primereact/resources/themes/saga-green/theme.css';
 // import 'primereact/resources/themes/luna-green/theme.css';
@@ -8,6 +8,7 @@ import 'primereact/resources/primereact.min.css';
 import 'primeicons/primeicons.css';
 import(/* webpackChunkName: "prFlex_AppCSS" */'primeflex/primeflex.css');
 // import 'primeflex/primeflex.css';
+// import(/* webpackChunkName: "blotFormatter2_AppCSS" */"@enzedonline/quill-blot-formatter2/dist/css/quill-blot-formatter2.css");
 
 // import(/* webpackChunkName: "layout_AppCSS" */'./layout/layout.css');
 import './layout/layout.css';
