@@ -12,6 +12,7 @@ let ex; const exModulePromises = ex = {
     prDropdown: import(/* webpackChunkName: "prDropdown_LinoComponentUtils" */"primereact/dropdown"),
     prInputText: import(/* webpackChunkName: "prInputText_LinoComponentUtils" */"primereact/inputtext"),
     queryString: import(/* webpackChunkName: "queryString_LinoComponentUtils" */"query-string"),
+    sc: import(/* webpackChunkName: "SiteContext_LinoComponentUtils" */"./SiteContext"),
     u: import(/* webpackChunkName: "LinoUtils_LinoComponentUtils" */"./LinoUtils"),
 };RegisterImportPool(ex);
 
@@ -159,7 +160,7 @@ export class LeafComponentBase extends Component {
     }
 
     innerHTML(dangerous, style={}) {
-        let v = this.getValue() || "\u00a0";
+        let v = this.getValue();  // || "\u00a0";
         if (v instanceof Object) v = JSON.stringify(v);
         if (dangerous) {
             return <div style={style} dangerouslySetInnerHTML={{__html: v}}/>
@@ -184,7 +185,7 @@ export class LeafComponentBase extends Component {
 
 
 export class LeafComponentDelayedValue extends LeafComponentBase {
-    static requiredModules = ["queryString"].concat(LeafComponentBase.requiredModules);
+    static requiredModules = ["queryString", "sc"].concat(LeafComponentBase.requiredModules);
     static propTypes = {
         ...LeafComponentBase.propTypes,
         hasOwnContext: PropTypes.bool.isRequired
@@ -193,18 +194,22 @@ export class LeafComponentDelayedValue extends LeafComponentBase {
         ...LeafComponentBase.defaultProps,
         hasOwnContext: false
     }
-    constructor(props, context) {
+
+    constructor(props, context, notSlave=false) {
         super(props, context);
+        this.delayed = !!props.elem.delayed_value;
         const masterRelate = {}
         if (!props.hasOwnContext) Object.assign(masterRelate,
             this.upController.actionHandler.masterRelateForSlave());
         this.state = {
-            ...this.state, value: null, data_url: null, ...masterRelate}
+            ...this.state, value: null, data_url: null, ...masterRelate,
+            key: this.upController.newSlug(),
+            haveCTX: this.delayed && !notSlave,
+        }
+        this.state.UCMount = !this.state.haveCTX || !this.delayed;
         this.actorID = props.elem.actor_id || (props.elem.name.includes('.')
             ? props.elem.name : `${props.urlParams.packId}.${props.elem.name}`);
 
-        this.delayed = props.elem.delayed_value;
-
         this.shouldComponentUpdate = this.shouldComponentUpdate.bind(this);
         this.getData = this.getData.bind(this);
         this.getValue = this.getValue.bind(this);
@@ -213,22 +218,24 @@ export class LeafComponentDelayedValue extends LeafComponentBase {
 
     onReady() {
         let val = super.getValue();
-        if (this.delayed) {
-            if (!this.props.hasOwnContext) this.setLeafRef({type: 'slave'});
-            this.upController.globals.panels[this.actorID] = this;
-            if (val !== null) this.getData(val.delayed_value_url)
-            else this.setState({value: "\u00a0", data_url: undefined});
-        } else {
+        if (!this.delayed) {
             this.setState({value: val});
+            return;
         }
+        if (!this.props.hasOwnContext) this.setLeafRef({type: 'slave'});
+        this.upController.globals.panels[this.actorID] = this;
+        if (val !== null) this.getData(val.delayed_value_url)
+        else this.setState({value: "\u00a0", data_url: undefined});
     }
 
     shouldComponentUpdate(nextProps, nextState, context) {
         const val = super.getValue();
-        let update;
-        if (!this.delayed) update = this.state.value !== nextState.value
-        // state.value is null when fetch in progress otherwise state.value is "\u00a0"
-        else update = this.state.value !== nextState.value || (this.state.value !== null &&
+        let update = (
+            this.state.value !== nextState.value ||
+            this.state.UCMount !== nextState.UCMount ||
+            this.state.ready !== nextState.ready
+        );
+        if (this.delayed) update = update || (this.state.value !== null &&
             (val || {}).delayed_value_url !== this.state.data_url);
         return update;
     }
@@ -253,11 +260,20 @@ export class LeafComponentDelayedValue extends LeafComponentBase {
     }
 
     getData(data_url) {
+        if (!this.state.UCMount) return;
+        // const params = this.upController.actionHandler.getParams();
+        const params = this.props.urlParams.controller.actionHandler.getParams();
+        // this.props.urlParams.controller.actionHandler.defaultStaticParams(params);
+        params[constants.URL_PARAM_REQUESTING_PANEL
+        ] = this.upController.actionHandler.refName;
+
         this.upController.actionHandler.silentFetch({
             // path: `${data_url}?${this.ex.queryString.default.stringify(this.upController.actionHandler.commonParams())}`
-            path: `${data_url}?${this.ex.queryString.default.stringify(this.upController.actionHandler.getParams())}`
+            path: `${data_url}?${this.ex.queryString.default.stringify(params)}`
         }).then((data) => {
-            this.setState({value: data.data, buttons: data.buttons, data_url: data_url});
+            this.setState({value: data.data, buttons: data.buttons,
+                           data_url: data_url});
+            this.upController.root.setState({});
         });
     }
 
@@ -270,6 +286,29 @@ export class LeafComponentDelayedValue extends LeafComponentBase {
     update() {
         this.getData(super.getValue().delayed_value_url);
     }
+
+    getChildren() {
+        throw "NotImplemented";
+    }
+
+    render() {
+        if (!this.state.ready) return null;
+        const up = this.props.urlParams, c = up.controller;
+        return this.state.haveCTX ? <this.ex.sc.URLContext
+            getChildren={(context) => {
+                const elem = this.getChildren();
+                return elem;
+            }}
+            params={c.actionHandler.masterRelateForSlave()}
+            parentContext={c}
+            path={`/api/${this.actorID.split(".").join("/")}`}
+            onContextReady={(context) => {
+                this.upController = context.controller;
+                this.setState({UCMount: true});
+            }}
+            simple={false}
+            summary={this}/> : this.getChildren();
+    }
 }
 
 
@@ -341,6 +380,7 @@ export class LeafComponentInput extends LeafComponentBase {
      * Find HTML input element
      */
     findHTMLInputElement(ref) {
+        if (!ref) return ref;
         if (ref.focusInput) ref = ref.focusInput
         else if (ref.inputRef) ref = ref.inputRef.current
         else if (ref.hasOwnProperty('getInput')) ref = ref.getInput();
@@ -359,8 +399,13 @@ export class LeafComponentInput extends LeafComponentBase {
 
     focus() {
         let ref = this.findHTMLInputElement(this.inputEl), input;
-        if (ref && ref.focus) {
-            ref.focus()
+        if (ref && !this.focusSet) {
+            if (ref.focus) {
+                ref.focus()
+            } else if (ref.click) {
+                ref.click();
+            }
+            this.focusSet = true
             this.select(ref);
         }
     }
@@ -395,7 +440,7 @@ export class LeafComponentInput extends LeafComponentBase {
             ref={this.onInputRef}
             style={{width: "100%"}}
             tabIndex={this.props.tabIndex}
-            value={this.getValue() || ""}
+            value={this.getValue()}
             {...this.inputState.inputProps}/>;
     }
 
@@ -405,11 +450,15 @@ export class LeafComponentInput extends LeafComponentBase {
     }
 
     onInputRef(ref) {
-        this.inputEl = ref;
         if (ref) {
-            let htmlInput = this.findHTMLInputElement(ref);
-            if (document.activeElement === htmlInput) return;
-            if (this.tabIndexMatch()) this.focus();
+            if (ref != this.inputEl) this.focusDone = false;
+            this.inputEl = ref;
+            if (!this.focusDone) {
+                let htmlInput = this.findHTMLInputElement(ref);
+                if (document.activeElement === htmlInput) return;
+                if (this.tabIndexMatch()) this.focus();
+                this.focusDone = true
+            }
         }
     }
 
@@ -493,7 +542,7 @@ export class LeafComponentInput extends LeafComponentBase {
         if (this.container) this.setCellStyle(this.container);
         return <Labeled {...this.props}
             actions={(this.context.field_actions || {})[this.props.elem.name] || []}
-            hide_label={hide_label || this.props.hide_label}
+            hide_label={hide_label}
             elem={this.props.elem} isFilled={this.filled()}>
             <div
                 className={this.ex.classNames.default(this.wrapperClasses)}
@@ -540,6 +589,8 @@ export class LeafComponentInputChoices extends LeafComponentInput {
 
     getLinoInput() {
         return <this.ex.prDropdown.Dropdown
+            // appendTo={this.inputEl ? this.findHTMLInputElement(this.inputEl) : window.App.topDiv}
+            autoFocus={true}
             itemTemplate={(item) => {
                 return <div dangerouslySetInnerHTML={{__html: item.text}}/>
             }}
@@ -551,7 +602,8 @@ export class LeafComponentInputChoices extends LeafComponentInput {
             }}
             optionLabel="text"
             options={this.options}
-            ref={this.onInputRef}
+            // panelStyle={{zIndex: "99999"}}
+            // ref={this.onInputRef}
             showClear={this.props.elem.field_options.allowBlank}
             style={{width: "100%"}}
             tabIndex={this.props.tabIndex}
@@ -563,7 +615,7 @@ export class LeafComponentInputChoices extends LeafComponentInput {
     }
 
     innerHTML() {
-        let v = super.getValue() || "\u00a0";
+        let v = super.getValue(); // || "\u00a0";
         // return <div style={{whiteSpace: "nowrap"}}>{v}</div>
         return <div /* style={{whiteSpace: "nowrap"}} */ dangerouslySetInnerHTML={{__html: v}}/>
     }
