@@ -196,8 +196,8 @@ const LinoComponents = {
             "prPanel", "prButton", "ltb"]);
         static iPool = Object.assign(ex, LeafComponentDelayedValue.iPool.copy());
 
-        render() {
-            if (!this.state.ready) return null;
+        getChildren() {
+            // if (!this.state.ready) return null;
             let style = {
                     height: "100%",
                     width: "100%",
@@ -218,7 +218,9 @@ const LinoComponents = {
                     //     console.log(args);
                     //     return this.props.elem.label
                     // }}
-                    icons={this.props.hasOwnContext ? <this.ex.ltb.LayoutButton/> :
+                    // icons={this.props.hasOwnContext ? <this.ex.ltb.LayoutButton/> :
+                    //     <div dangerouslySetInnerHTML={{__html: this.state.buttons}} />
+                    icons={!this.state.buttons ? <this.ex.ltb.LayoutButton/> :
                         <div dangerouslySetInnerHTML={{__html: this.state.buttons}} />
                         // <this.ex.prButton.Button
                         //     className="p-transparent-button"
@@ -284,8 +286,13 @@ const LinoComponents = {
     DisplayElement: class DisplayElement extends LeafComponentDelayedValue {
         static requiredModules = ["prFieldset"].concat(LeafComponentDelayedValue.requiredModules);
         static iPool = Object.assign(ex, LeafComponentDelayedValue.iPool.copy());
-        render() {
-            if (!this.state.ready) return null;
+
+        constructor(props, context) {
+            super(props, context, true);
+        }
+
+        getChildren() {
+            // if (!this.state.ready) return null;
             let unit = (this.state.value === null && this.delayed)
                 ? <LinoProgressSpinner />
                 : this.innerHTML(constants.DANGEROUS_HTML);
