@@ -71,10 +71,12 @@ describe("noi/URLContext.ts", () => {
         });
         expect(dialogs).toEqual(0);
     });
-    
+
     it("test insert window footer on dashboard", async () => {
-        await page.waitForSelector("div.dashboard-item>h2::-p-text(My Tickets)");
-        const mas = await page.$("div.dashboard-item>h2::-p-text(My Tickets)");
+        // await page.waitForSelector("div.dashboard-item>h2::-p-text(My Tickets)");
+        // const mas = await page.$("div.dashboard-item>h2::-p-text(My Tickets)");
+        await page.waitForSelector("div.dashboard-item>h2::-p-text(Tickets to work)");
+        const mas = await page.$("div.dashboard-item>h2::-p-text(Tickets to work)");
         await mas.scrollIntoView();
         const insertButton = await mas.$("a.pi-plus-circle");
         await mas.dispose();
