@@ -232,8 +232,11 @@ class ApiList(View):
                       overridden_column_headers=ar.actor.override_column_headers(
                           ar),
                       no_data_text=ar.no_data_text,
-                      plain_toolbar=plain_toolbar,  # 20250713
-                      title=ar.get_title())
+                      plain_toolbar=plain_toolbar)
+            if False:  # ar.is_on_main_actor:
+                kw.update(title=ar.get_breadcrumbs())
+            else:
+                kw.update(title=ar.get_title())
 
             if ar.actor.start_at_bottom and ar.offset is None:
                 offset = (kw["count"] // ar.limit) * ar.limit
@@ -260,6 +263,7 @@ class SmartId(View):
         # request.GET.get("Authorization code")
         pass
 
+
 class SmartIdEntry(View):
     def get(self, request):
 
@@ -362,7 +366,7 @@ class Choices(View):
             field = ba.action.get_param_elem(field)
             qs, row2dict = choices_for_field(
                 ba.create_request(request=request), ba.action, field)
-            emptyValue = '<br/>'
+            emptyValue = ''
         elif field is not None:
             # NOTE: if you define a *parameter* with the same name as
             # some existing *data element* name, then the parameter
@@ -438,7 +442,8 @@ class DelayedValue(View):
                 slave_rpt = requested_actor(*field.split('.'))
             else:
                 slave_rpt = requested_actor(app_label, field)
-            sar = slave_rpt.create_request(parent=ar, master_instance=ar.selected_rows[0])
+            sar = slave_rpt.create_request(
+                parent=ar, master_instance=ar.selected_rows[0])
             buttons = mark_safe(" ".join(
                     [tostring(b) for b in sar.plain_toolbar_buttons()]))
         except http.Http404 as e:
@@ -801,8 +806,9 @@ class Index(View):
                 request=request,
                 user=user,  # Current user
                 site_name=settings.SITE.project_dir.name,
+                ar=ar,
+                theme_name=ui.primereact_theme_name,
             )
-            context.update(ar=ar)
 
             context = ar.get_printable_context(**context)
             env = settings.SITE.plugins.jinja.renderer.jinja_env
@@ -829,8 +835,7 @@ class UserSettings(View):
 
         def getit():
             # print(20200419, settings.SITE.build_media_url(*settings.SITE.plugins.react.renderer.lino_js_parts()))
-            if (settings.SITE.developer_site_cache
-                    and not settings.SITE.never_build_site_cache):
+            if settings.SITE.developer_site_cache:
                 settings.SITE.plugins.react.renderer.build_js_cache(False)
 
             user_settings = dict(
@@ -841,7 +846,7 @@ class UserSettings(View):
                 # [d.serialize() for d in u.get_preferences().dashboard_items],
                 user_lang=u.language or get_language(),
                 site_lang=get_language(),
-                site_data=settings.SITE.build_site_cache_url(
+                site_data=settings.SITE.build_media_url(
                     *settings.SITE.plugins.react.renderer.lino_js_parts()),
                 user_menu=settings.SITE.get_site_menu(
                     (su or u).user_type, request),
